@@ -20,7 +20,7 @@ class FileHandlers:
                     self.set_permissions(self.path)
                     self.own_log, self.sys_log = self.initialize_loggers()
                     self.set_permissions(self.log_file)
-            except (PermissionError, FileNotFoundError, AttributeError) as e:
+            except (PermissionError, FileNotFoundError, KeyError) as e:
                 print(e)
                 print('Run with sudo first time to set permissions')
                 sys.exit(1)
@@ -40,29 +40,40 @@ class FileHandlers:
     def make_directories(self):
         os.makedirs(self.path, exist_ok=True)
 
+    def set_permissions(self, path, gid=33):
+        try:
+            os.chown(path, int(os.environ['SUDO_GID']), gid)
+            self.file_or_dir(path)
+        except KeyError:
+            try:
+                os.chown(path, int(os.getuid()), gid)
+                self.file_or_dir(path)
+            except PermissionError as e:
+                raise e
+
     @staticmethod
-    def set_permissions(path, gid=33):
-        os.chown(path, int(os.environ['SUDO_GID']), gid)
+    def file_or_dir(path):
         if os.path.isdir(path):
             os.chmod(path, 0o770)
         elif os.path.isfile(path):
             os.chmod(path, 0o665)
 
     def initialize_loggers(self):
-        sys_log = logging.getLogger('domains_api')
+        sys_log = logging.getLogger('Domains API')
         own_log = logging.getLogger(__name__)
         if self.log_level == 'debug':
-            sys_log.setLevel(logging.DEBUG)
+            level = logging.DEBUG
         elif self.log_level == 'warning':
-            sys_log.setLevel(logging.WARNING)
+            level = logging.WARNING
         else:
-            sys_log.setLevel(logging.INFO)
-        own_log.setLevel(logging.WARNING)
+            level = logging.INFO
+        sys_log.setLevel(level)
+        own_log.setLevel(level)
         fh = logging.FileHandler(self.log_file)
         sh = logging.StreamHandler(sys.stdout)
-        formatter = logging.Formatter('[%(levelname)s]|%(asctime)s|%(message)s',
-                                      datefmt='%d %b %Y %H:%M:%S')
-        sh_formatter = logging.Formatter('[%(levelname)s]|[%(name)s]|%(asctime)s| %(message)s',
+        formatter = logging.Formatter('[%(levelname)s][%(name)s][%(asctime)s] %(message)s',
+                                      datefmt='%Y-%m-%d %H:%M:%S')
+        sh_formatter = logging.Formatter('[%(name)s][%(levelname)s][%(asctime)s] %(message)s',
                                          datefmt='%Y-%m-%d %H:%M:%S')
         fh.setFormatter(formatter)
         sh.setFormatter(sh_formatter)
@@ -74,8 +85,10 @@ class FileHandlers:
     def log(self, msg, level='info'):
         if level == 'info':
             self.sys_log.info(msg)
+            self.own_log.info(msg)
         elif level == 'debug':
             self.sys_log.debug(msg)
+            self.own_log.debug(msg)
         elif level == 'warning':
             self.sys_log.warning(msg)
             self.own_log.warning(msg)
@@ -118,4 +131,4 @@ class FileHandlers:
 
 if __name__ == '__main__':
     fhs = FileHandlers()
-    fhs.log('Testing', 'info')
\ No newline at end of file
+    fhs.log('Testing', 'info')
